From d0ff0fe53adcc87b08f9a73357a2dc878817484e Mon Sep 17 00:00:00 2001
From: CloudQuery Bot <102256036+cq-bot@users.noreply.github.com>
Date: Sun, 1 Sep 2024 03:52:07 +0300
Subject: [PATCH 1/6] fix(deps): Update dependency black to v24.8.0 (#110)
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
This PR contains the following updates:
| Package | Update | Change |
|---|---|---|
| [black](https://togithub.com/psf/black) ([changelog](https://togithub.com/psf/black/blob/main/CHANGES.md)) | minor | `==24.4.2` -> `==24.8.0` |
---
### Release Notes
psf/black (black)
### [`v24.8.0`](https://togithub.com/psf/black/blob/HEAD/CHANGES.md#2480)
[Compare Source](https://togithub.com/psf/black/compare/24.4.2...24.8.0)
##### Stable style
- Fix crash when `# fmt: off` is used before a closing parenthesis or bracket. ([#4363](https://togithub.com/psf/black/issues/4363))
##### Packaging
- Packaging metadata updated: docs are explictly linked, the issue tracker is now also
linked. This improves the PyPI listing for Black. ([#4345](https://togithub.com/psf/black/issues/4345))
##### Parser
- Fix regression where Black failed to parse a multiline f-string containing another
multiline string ([#4339](https://togithub.com/psf/black/issues/4339))
- Fix regression where Black failed to parse an escaped single quote inside an f-string
([#4401](https://togithub.com/psf/black/issues/4401))
- Fix bug with Black incorrectly parsing empty lines with a backslash ([#4343](https://togithub.com/psf/black/issues/4343))
- Fix bugs with Black's tokenizer not handling `\{` inside f-strings very well ([#4422](https://togithub.com/psf/black/issues/4422))
- Fix incorrect line numbers in the tokenizer for certain tokens within f-strings
([#4423](https://togithub.com/psf/black/issues/4423))
##### Performance
- Improve performance when a large directory is listed in `.gitignore` ([#4415](https://togithub.com/psf/black/issues/4415))
##### *Blackd*
- Fix blackd (and all extras installs) for docker container ([#4357](https://togithub.com/psf/black/issues/4357))
---
### Configuration
📅 **Schedule**: Branch creation - "before 4am on the first day of the month" (UTC), Automerge - At any time (no schedule defined).
🚦 **Automerge**: Disabled by config. Please merge this manually once you are satisfied.
â™» **Rebasing**: Whenever PR becomes conflicted, or you tick the rebase/retry checkbox.
🔕 **Ignore**: Close this PR and you won't be reminded about this update again.
---
- [ ] If you want to rebase/retry this PR, check this box
---
This PR has been generated by [Renovate Bot](https://togithub.com/renovatebot/renovate).
---
requirements.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/requirements.txt b/requirements.txt
index 2426dcc..dee05c8 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -1,4 +1,4 @@
-black==24.4.2
+black==24.8.0
grpcio-tools==1.65.2
grpcio==1.65.2
protobuf==5.27.3
From 1dd587ecd283770189691ff994123d3674869dc5 Mon Sep 17 00:00:00 2001
From: CloudQuery Bot <102256036+cq-bot@users.noreply.github.com>
Date: Sun, 1 Sep 2024 03:57:20 +0300
Subject: [PATCH 2/6] fix(deps): Update dependency grpcio to v1.66.1 (#111)
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
This PR contains the following updates:
| Package | Update | Change |
|---|---|---|
| [grpcio](https://grpc.io) ([source](https://togithub.com/grpc/grpc)) | minor | `==1.65.2` -> `==1.66.1` |
---
### Release Notes
grpc/grpc (grpcio)
### [`v1.66.1`](https://togithub.com/grpc/grpc/releases/tag/v1.66.1)
[Compare Source](https://togithub.com/grpc/grpc/compare/v1.66.0...v1.66.1)
This is release gRPC Core 1.66.1 (gladiator).
For gRPC documentation, see [grpc.io](https://grpc.io/). For previous releases, see [Releases](https://togithub.com/grpc/grpc/releases).
This release contains refinements, improvements, and bug fixes.
### Core
- Enable EDS dualstack support by default ([https://github.com/grpc/grpc/pull/37545](https://togithub.com/grpc/grpc/pull/37545))
### [`v1.66.0`](https://togithub.com/grpc/grpc/releases/tag/v1.66.0)
[Compare Source](https://togithub.com/grpc/grpc/compare/v1.65.5...v1.66.0)
This is release 1.66.0 ([gladiator](https://togithub.com/grpc/grpc/blob/master/doc/g_stands_for.md)) of gRPC Core.
For gRPC documentation, see [grpc.io](https://grpc.io/). For previous releases, see [Releases](https://togithub.com/grpc/grpc/releases).
This release contains refinements, improvements, and bug fixes, with highlights listed below.
## Core
- \[Python Otel] Manage call tracer life cycle use call arena. (v1.66.x backport). ([#37479](https://togithub.com/grpc/grpc/pull/37479))
- \[BoringSSL] Update third_party/boringssl-with-bazel. ([#37223](https://togithub.com/grpc/grpc/pull/37223))
- \[Dep] Upgrading Protobuf to v27.2. ([#36753](https://togithub.com/grpc/grpc/pull/36753))
- \[Gpr_To_Absl_Logging] Fixing bugs . ([#36961](https://togithub.com/grpc/grpc/pull/36961))
- \[chttp2] don't access endpoint in transport ops if it's already been destroyed. ([#36921](https://togithub.com/grpc/grpc/pull/36921))
## C++
- \[OTel C++] Fix race when adding and removing callbacks ([#37485](https://togithub.com/grpc/grpc/issues/37485)). ([#37508](https://togithub.com/grpc/grpc/pull/37508))
- \[RlsLB] Fix Deadlock ([#37459](https://togithub.com/grpc/grpc/issues/37459)). ([#37502](https://togithub.com/grpc/grpc/pull/37502))
## Python
- \[Python Distrib] Change warning to RuntimeError for version incompatibility (v1.66.x backport). ([#37477](https://togithub.com/grpc/grpc/pull/37477))
- Fix issues/36613. ([#37022](https://togithub.com/grpc/grpc/pull/37022))
- \[fix] updated invocation_metadata return type hint. ([#36894](https://togithub.com/grpc/grpc/pull/36894))
- \[Release] Add warning about PyPi latest version not necessarily matching Github latest version. ([#36965](https://togithub.com/grpc/grpc/pull/36965))
## Ruby
- \[ruby] Update google-protobuf dep to allow 3.x and 4.x versions. ([#36982](https://togithub.com/grpc/grpc/pull/36982))
- \[ruby] improve the way completion queue pluck operations handle signals and process shutdown. ([#36903](https://togithub.com/grpc/grpc/pull/36903))
### [`v1.65.5`](https://togithub.com/grpc/grpc/releases/tag/v1.65.5)
[Compare Source](https://togithub.com/grpc/grpc/compare/v1.65.4...v1.65.5)
This is release gRPC Core 1.65.5 (gnarly).
For gRPC documentation, see [grpc.io](https://grpc.io/). For previous releases, see [Releases](https://togithub.com/grpc/grpc/releases).
This release contains refinements, improvements, and bug fixes.
- \[OTel C++] Fix race when adding and removing callbacks ([#37509](https://togithub.com/grpc/grpc/issues/37509))
- \[RlsLB] Fix Deadlock ([#37503](https://togithub.com/grpc/grpc/issues/37503))
- \[Python Otel] Manage call tracer life cycle use call arena. (v1.65.x backport) ([#37478](https://togithub.com/grpc/grpc/issues/37478))
### [`v1.65.4`](https://togithub.com/grpc/grpc/releases/tag/v1.65.4)
[Compare Source](https://togithub.com/grpc/grpc/compare/v1.65.2...v1.65.4)
This is release gRPC Core 1.65.4 (gnarly).
For gRPC documentation, see [grpc.io](https://grpc.io/). For previous releases, see [Releases](https://togithub.com/grpc/grpc/releases).
This release contains refinements, improvements, and bug fixes.
- [https://github.com/grpc/grpc/pull/37359](https://togithub.com/grpc/grpc/pull/37359) Fix a bug in hpack error handling
---
### Configuration
📅 **Schedule**: Branch creation - "before 4am on the first day of the month" (UTC), Automerge - At any time (no schedule defined).
🚦 **Automerge**: Disabled by config. Please merge this manually once you are satisfied.
â™» **Rebasing**: Whenever PR becomes conflicted, or you tick the rebase/retry checkbox.
🔕 **Ignore**: Close this PR and you won't be reminded about this update again.
---
- [ ] If you want to rebase/retry this PR, check this box
---
This PR has been generated by [Renovate Bot](https://togithub.com/renovatebot/renovate).
---
requirements.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/requirements.txt b/requirements.txt
index dee05c8..83ce53f 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -1,6 +1,6 @@
black==24.8.0
grpcio-tools==1.65.2
-grpcio==1.65.2
+grpcio==1.66.1
protobuf==5.27.3
pyarrow==17.0.0
pytest==8.3.2
From da1d6bae735ec0b231a8da6ae039924247bbba63 Mon Sep 17 00:00:00 2001
From: CloudQuery Bot <102256036+cq-bot@users.noreply.github.com>
Date: Sun, 1 Sep 2024 04:52:19 +0300
Subject: [PATCH 3/6] fix(deps): Update dependency grpcio-tools to v1.66.1
(#113)
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
This PR contains the following updates:
| Package | Update | Change |
|---|---|---|
| [grpcio-tools](https://grpc.io) | minor | `==1.65.2` -> `==1.66.1` |
---
### Configuration
📅 **Schedule**: Branch creation - "before 4am on the first day of the month" (UTC), Automerge - At any time (no schedule defined).
🚦 **Automerge**: Disabled by config. Please merge this manually once you are satisfied.
â™» **Rebasing**: Whenever PR becomes conflicted, or you tick the rebase/retry checkbox.
🔕 **Ignore**: Close this PR and you won't be reminded about this update again.
---
- [ ] If you want to rebase/retry this PR, check this box
---
This PR has been generated by [Renovate Bot](https://togithub.com/renovatebot/renovate).
---
requirements.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/requirements.txt b/requirements.txt
index 83ce53f..350dd9f 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -1,5 +1,5 @@
black==24.8.0
-grpcio-tools==1.65.2
+grpcio-tools==1.66.1
grpcio==1.66.1
protobuf==5.27.3
pyarrow==17.0.0
From eee8a7510bcdc58e0330787e33e706376d4291b4 Mon Sep 17 00:00:00 2001
From: CloudQuery Bot <102256036+cq-bot@users.noreply.github.com>
Date: Sun, 1 Sep 2024 04:53:14 +0300
Subject: [PATCH 4/6] fix(deps): Update dependency protobuf to v5.28.0 (#114)
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
This PR contains the following updates:
| Package | Update | Change |
|---|---|---|
| [protobuf](https://developers.google.com/protocol-buffers/) | minor | `==5.27.3` -> `==5.28.0` |
---
### Configuration
📅 **Schedule**: Branch creation - "before 4am on the first day of the month" (UTC), Automerge - At any time (no schedule defined).
🚦 **Automerge**: Disabled by config. Please merge this manually once you are satisfied.
â™» **Rebasing**: Whenever PR becomes conflicted, or you tick the rebase/retry checkbox.
🔕 **Ignore**: Close this PR and you won't be reminded about this update again.
---
- [ ] If you want to rebase/retry this PR, check this box
---
This PR has been generated by [Renovate Bot](https://togithub.com/renovatebot/renovate).
---
requirements.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/requirements.txt b/requirements.txt
index 350dd9f..b3fb4d9 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -1,6 +1,6 @@
black==24.8.0
grpcio-tools==1.66.1
grpcio==1.66.1
-protobuf==5.27.3
+protobuf==5.28.0
pyarrow==17.0.0
pytest==8.3.2
diff --git a/cloudquery/discovery_v1/discovery_pb2_grpc.py b/cloudquery/discovery_v1/discovery_pb2_grpc.py
index 287f7b5..1ce89ff 100644
--- a/cloudquery/discovery_v1/discovery_pb2_grpc.py
+++ b/cloudquery/discovery_v1/discovery_pb2_grpc.py
@@ -5,10 +5,8 @@
from cloudquery.discovery_v1 import discovery_pb2 as cloudquery_dot_discovery__v1_dot_discovery__pb2
-GRPC_GENERATED_VERSION = '1.65.2'
+GRPC_GENERATED_VERSION = '1.66.1'
GRPC_VERSION = grpc.__version__
-EXPECTED_ERROR_RELEASE = '1.66.0'
-SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False
try:
@@ -18,15 +16,12 @@
_version_not_supported = True
if _version_not_supported:
- warnings.warn(
+ raise RuntimeError(
f'The grpc package installed is at version {GRPC_VERSION},'
+ f' but the generated code in cloudquery/discovery_v1/discovery_pb2_grpc.py depends on'
+ f' grpcio>={GRPC_GENERATED_VERSION}.'
+ f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
+ f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
- + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
- + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
- RuntimeWarning
)
diff --git a/cloudquery/plugin_v3/plugin_pb2_grpc.py b/cloudquery/plugin_v3/plugin_pb2_grpc.py
index 35ed79a..62e36e2 100644
--- a/cloudquery/plugin_v3/plugin_pb2_grpc.py
+++ b/cloudquery/plugin_v3/plugin_pb2_grpc.py
@@ -5,10 +5,8 @@
from cloudquery.plugin_v3 import plugin_pb2 as cloudquery_dot_plugin__v3_dot_plugin__pb2
-GRPC_GENERATED_VERSION = '1.65.2'
+GRPC_GENERATED_VERSION = '1.66.1'
GRPC_VERSION = grpc.__version__
-EXPECTED_ERROR_RELEASE = '1.66.0'
-SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False
try:
@@ -18,15 +16,12 @@
_version_not_supported = True
if _version_not_supported:
- warnings.warn(
+ raise RuntimeError(
f'The grpc package installed is at version {GRPC_VERSION},'
+ f' but the generated code in cloudquery/plugin_v3/plugin_pb2_grpc.py depends on'
+ f' grpcio>={GRPC_GENERATED_VERSION}.'
+ f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
+ f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
- + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
- + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
- RuntimeWarning
)
From 66586d0c82f78616434d8013f68b4e027c0a686f Mon Sep 17 00:00:00 2001
From: CloudQuery Bot <102256036+cq-bot@users.noreply.github.com>
Date: Wed, 4 Sep 2024 15:37:05 +0300
Subject: [PATCH 6/6] chore(main): Release v0.0.34 (#112)
:robot: I have created a release *beep* *boop*
---
## [0.0.34](https://github.com/cloudquery/plugin-pb-python/compare/v0.0.33...v0.0.34) (2024-09-01)
### Bug Fixes
* **deps:** Update dependency black to v24.8.0 ([#110](https://github.com/cloudquery/plugin-pb-python/issues/110)) ([d0ff0fe](https://github.com/cloudquery/plugin-pb-python/commit/d0ff0fe53adcc87b08f9a73357a2dc878817484e))
* **deps:** Update dependency grpcio to v1.66.1 ([#111](https://github.com/cloudquery/plugin-pb-python/issues/111)) ([1dd587e](https://github.com/cloudquery/plugin-pb-python/commit/1dd587ecd283770189691ff994123d3674869dc5))
* **deps:** Update dependency grpcio-tools to v1.66.1 ([#113](https://github.com/cloudquery/plugin-pb-python/issues/113)) ([da1d6ba](https://github.com/cloudquery/plugin-pb-python/commit/da1d6bae735ec0b231a8da6ae039924247bbba63))
* **deps:** Update dependency protobuf to v5.28.0 ([#114](https://github.com/cloudquery/plugin-pb-python/issues/114)) ([eee8a75](https://github.com/cloudquery/plugin-pb-python/commit/eee8a7510bcdc58e0330787e33e706376d4291b4))
* Generate Python Code from `plugin-pb` ([#115](https://github.com/cloudquery/plugin-pb-python/issues/115)) ([1c6860e](https://github.com/cloudquery/plugin-pb-python/commit/1c6860e75dad4c3511096100765d3413568f2d4c))
---
This PR was generated with [Release Please](https://github.com/googleapis/release-please). See [documentation](https://github.com/googleapis/release-please#release-please).
---
.release-please-manifest.json | 2 +-
CHANGELOG.md | 11 +++++++++++
setup.py | 2 +-
3 files changed, 13 insertions(+), 2 deletions(-)
diff --git a/.release-please-manifest.json b/.release-please-manifest.json
index 25bf810..9efa5ca 100644
--- a/.release-please-manifest.json
+++ b/.release-please-manifest.json
@@ -1,3 +1,3 @@
{
- ".": "0.0.33"
+ ".": "0.0.34"
}
diff --git a/CHANGELOG.md b/CHANGELOG.md
index aa81b31..94fd615 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,16 @@
# Changelog
+## [0.0.34](https://github.com/cloudquery/plugin-pb-python/compare/v0.0.33...v0.0.34) (2024-09-01)
+
+
+### Bug Fixes
+
+* **deps:** Update dependency black to v24.8.0 ([#110](https://github.com/cloudquery/plugin-pb-python/issues/110)) ([d0ff0fe](https://github.com/cloudquery/plugin-pb-python/commit/d0ff0fe53adcc87b08f9a73357a2dc878817484e))
+* **deps:** Update dependency grpcio to v1.66.1 ([#111](https://github.com/cloudquery/plugin-pb-python/issues/111)) ([1dd587e](https://github.com/cloudquery/plugin-pb-python/commit/1dd587ecd283770189691ff994123d3674869dc5))
+* **deps:** Update dependency grpcio-tools to v1.66.1 ([#113](https://github.com/cloudquery/plugin-pb-python/issues/113)) ([da1d6ba](https://github.com/cloudquery/plugin-pb-python/commit/da1d6bae735ec0b231a8da6ae039924247bbba63))
+* **deps:** Update dependency protobuf to v5.28.0 ([#114](https://github.com/cloudquery/plugin-pb-python/issues/114)) ([eee8a75](https://github.com/cloudquery/plugin-pb-python/commit/eee8a7510bcdc58e0330787e33e706376d4291b4))
+* Generate Python Code from `plugin-pb` ([#115](https://github.com/cloudquery/plugin-pb-python/issues/115)) ([1c6860e](https://github.com/cloudquery/plugin-pb-python/commit/1c6860e75dad4c3511096100765d3413568f2d4c))
+
## [0.0.33](https://github.com/cloudquery/plugin-pb-python/compare/v0.0.32...v0.0.33) (2024-08-01)
diff --git a/setup.py b/setup.py
index d9158c5..fb149d4 100644
--- a/setup.py
+++ b/setup.py
@@ -37,7 +37,7 @@
]
setuptools.setup(
name=name,
- version="0.0.33",
+ version="0.0.34",
description=description,
long_description=long_description,
author="CloudQuery LTD",
From 1c6860e75dad4c3511096100765d3413568f2d4c Mon Sep 17 00:00:00 2001
From: CloudQuery Bot <102256036+cq-bot@users.noreply.github.com>
Date: Sun, 1 Sep 2024 11:02:27 +0300
Subject: [PATCH 5/6] fix: Generate Python Code from `plugin-pb` (#115)
This PR was created by a scheduled workflow to regenerate the Python code from `plugin-pb`.
---
cloudquery/discovery_v1/discovery_pb2.py | 12 +++++++++++-
cloudquery/discovery_v1/discovery_pb2_grpc.py | 9 ++-------
cloudquery/plugin_v3/plugin_pb2.py | 12 +++++++++++-
cloudquery/plugin_v3/plugin_pb2_grpc.py | 9 ++-------
4 files changed, 26 insertions(+), 16 deletions(-)
diff --git a/cloudquery/discovery_v1/discovery_pb2.py b/cloudquery/discovery_v1/discovery_pb2.py
index b680c71..f359702 100644
--- a/cloudquery/discovery_v1/discovery_pb2.py
+++ b/cloudquery/discovery_v1/discovery_pb2.py
@@ -1,12 +1,22 @@
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
+# NO CHECKED-IN PROTOBUF GENCODE
# source: cloudquery/discovery_v1/discovery.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
+from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
+_runtime_version.ValidateProtobufRuntimeVersion(
+ _runtime_version.Domain.PUBLIC,
+ 5,
+ 27,
+ 2,
+ '',
+ 'cloudquery/discovery_v1/discovery.proto'
+)
# @@protoc_insertion_point(imports)
_sym_db = _symbol_database.Default()
@@ -1,12 +1,22 @@
# source: cloudquery/discovery_v1/discovery.proto
-# Protobuf Python Version: 5.26.1
+# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
diff --git a/cloudquery/plugin_v3/plugin_pb2.py b/cloudquery/plugin_v3/plugin_pb2.py
index b24f77f..0e07e75 100644
--- a/cloudquery/plugin_v3/plugin_pb2.py
+++ b/cloudquery/plugin_v3/plugin_pb2.py
@@ -1,12 +1,22 @@
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
+# NO CHECKED-IN PROTOBUF GENCODE
# source: cloudquery/plugin_v3/plugin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
+from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
+_runtime_version.ValidateProtobufRuntimeVersion(
+ _runtime_version.Domain.PUBLIC,
+ 5,
+ 27,
+ 2,
+ '',
+ 'cloudquery/plugin_v3/plugin.proto'
+)
# @@protoc_insertion_point(imports)
_sym_db = _symbol_database.Default()
@@ -1,12 +1,22 @@
# source: cloudquery/plugin_v3/plugin.proto
-# Protobuf Python Version: 5.26.1
+# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor